==> qmmp_1.4.3.orig.tar.bz2: qmmp-1.4.3/src/plugins/General/hal/translations/hal_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="30"/>
        <source>HAL Plugin</source>
        <translation>HAL-liitännäinen</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="50"/>
        <source>About HAL Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="51"/>
        <source>Qmmp HAL Plugin</source>
        <translation>Qmmp:n HAL-liitännäinen</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Toteuttanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="165"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Lisää CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="171"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation>HAL-liitännäisen asetukset</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Lisää kappaleet soittolistaan automaattisesti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Poista kappaleet soittolistalta automaattisesti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation>Irrotettavan laitteen havaitseminen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation>Lisää tiedostot soittolistaan automaattisesti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation>Poista tiedostot soittolistasta automaattisesti</translation>
    </message>
</context>
</TS>

==> qmmp-1.5.4.tar.bz2: qmmp-1.5.4/src/plugins/General/hal/translations/hal_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="30"/>
        <source>HAL Plugin</source>
        <translation>HAL Plugin</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="50"/>
        <source>About HAL Plugin</source>
        <translation>Tietoja: HAL Plugin</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="51"/>
        <source>Qmmp HAL Plugin</source>
        <translation>Qmmp HAL Plugin</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation>Tämä laajennus havaitsee HAL:n avulla irrotettavat laitteet</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Kirjoittanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation>Perustuu Solid (KDE hardware library)</translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="164"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Lisää CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="170"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Lisää asema &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation>HAL-liitännäisen asetukset</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation>Audio CD:n tunnistus</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Lisää kappaleet soittolistaan automaattisesti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Poista kappaleet soittolistalta automaattisesti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation>Irrotettavan laitteen havaitseminen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation>Lisää tiedostot soittolistaan automaattisesti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation>Poista tiedostot soittolistasta automaattisesti</translation>
    </message>
</context>
</TS>
